@@ -412,7 +412,7 @@ on_logical_toggled (GtkMenuItem     *menuitem,
     if (prefs.mode == BASIC_MODE) return;
     if (prefs.mode == PAPER_MODE) return;
 
-    prefs.vis_logic = 
+	prefs.vis_logic = 
         gtk_check_menu_item_get_active((GtkCheckMenuItem *) menuitem);
     set_widget_visibility (button_box_xml, "table_bin_buttons",
         prefs.vis_logic);
@@ -476,7 +476,8 @@ on_basic_mode_toggled (GtkMenuItem     *menuitem,
     display_module_notation_activate (current_status.notation);
 
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "display_control"));
-    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), prefs.vis_dispctrl);
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), prefs.vis_dispctrl);
+    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
 
     update_active_buttons (current_status.number, current_status.notation);
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "functions"));
@@ -529,17 +530,21 @@ on_scientific_mode_toggled (GtkMenuItem *menuitem,
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "functions"));
     gtk_widget_set_sensitive (menu_item, TRUE);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), prefs.vis_funcs);
+    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
     
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "display_control"));
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), prefs.vis_dispctrl);
+    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
     
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "logical"));
     gtk_widget_set_sensitive (menu_item, TRUE);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), prefs.vis_logic);
+    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
     
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "standard"));
     gtk_widget_set_sensitive (menu_item, TRUE);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menu_item), prefs.vis_standard);
+    gtk_check_menu_item_toggled (GTK_CHECK_MENU_ITEM(menu_item));
     
     menu_item = GTK_WIDGET(gtk_builder_get_object (main_window_xml, "base_units"));
     gtk_widget_set_sensitive (menu_item, TRUE);
@@ -1025,7 +1030,7 @@ void ms_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
     index = GPOINTER_TO_INT(user_data);
     if (index >= memory.len) {
         index = memory.len;
-        memory.data = (G_REAL *) realloc (memory.data, (index + 1) * sizeof(G_REAL));
+        memory.data = (G_REAL *) g_realloc (memory.data, (index + 1) * sizeof(G_REAL));
         memory.len++;
     }
     memory.data[index] = display_result_get_double(current_status.number);
@@ -1111,7 +1116,7 @@ void mc_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
         for (counter = index; counter < (memory.len - 1); counter++) 
             memory.data[counter] = memory.data[counter + 1];
         memory.len--;
-        memory.data = (G_REAL *) realloc (memory.data, memory.len * sizeof(G_REAL));
+        memory.data = (G_REAL *) g_realloc (memory.data, memory.len * sizeof(G_REAL));
     }
 }
 
@@ -1187,7 +1192,7 @@ void on_prefs_ufadd_clicked (GtkButton *button, gpointer user_data)
     }
         
     nr_user_functions = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(prefs_user_function_store), NULL);
-    user_function = (s_user_function *) realloc (user_function, (nr_user_functions + 2) * sizeof(s_user_function));
+    user_function = (s_user_function *) g_realloc (user_function, (nr_user_functions + 2) * sizeof(s_user_function));
     user_function[nr_user_functions + 1].name = NULL;
     
     user_function[nr_user_functions].name = name;
@@ -1224,7 +1229,7 @@ void on_prefs_ufdelete_clicked (GtkButton *button, gpointer user_data)
         memcpy (&user_function[counter], &user_function[counter+1], sizeof(s_user_function));
     
     nr_user_functions--;
-    user_function = (s_user_function *) realloc (user_function, (nr_user_functions + 1) * sizeof(s_user_function));
+    user_function = (s_user_function *) g_realloc (user_function, (nr_user_functions + 1) * sizeof(s_user_function));
     
     user_function[nr_user_functions].name = NULL;
 }
@@ -1292,7 +1297,7 @@ void on_prefs_cadd_clicked (GtkButton *button, gpointer user_data)
     }
         
     nr_consts = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(prefs_constant_store), NULL);
-    constant = (s_constant *) realloc (constant, (nr_consts + 2) * sizeof(s_constant));
+    constant = (s_constant *) g_realloc (constant, (nr_consts + 2) * sizeof(s_constant));
     constant[nr_consts + 1].name = NULL;
     
     constant[nr_consts].name = name;
@@ -1328,7 +1333,7 @@ void on_prefs_cdelete_clicked (GtkButton *button, gpointer user_data)
         memcpy (&constant[counter], &constant[counter+1], sizeof(s_constant));
     
     nr_consts--;
-    constant = (s_constant *) realloc (constant, (nr_consts + 1) * sizeof(s_constant));
+    constant = (s_constant *) g_realloc (constant, (nr_consts + 1) * sizeof(s_constant));
     
     constant[nr_consts].name = NULL;
 }
