@@ -135,7 +135,7 @@ static void apply_object_data (s_operation_map operation_map[],
 	
 	counter = 0;
 	while (function_map[counter].button_name != NULL) {
-		func = (void *) malloc (sizeof (function_map[counter].func));
+		func = (void *) g_malloc (sizeof (function_map[counter].func));
 		memcpy (func, function_map[counter].func, sizeof (function_map[counter].func));
 		object = G_OBJECT (gtk_builder_get_object (button_box_xml, 
 			function_map[counter].button_name));
@@ -151,7 +151,11 @@ static void apply_object_data (s_operation_map operation_map[],
 
 static void set_scientific_object_data ()
 {
-	s_operation_map	operation_map[] = {
+	/* 20140316, simon: all these structs shall be static to have global scope.
+	 * fixes sf.net #104.
+	 */
+	 
+	static s_operation_map	operation_map[] = {
 		{"button_pow", "^", '^'},
 		{"button_lsh", "<<", '<'},
 		{"button_mod", "MOD", 'm'},
@@ -169,7 +173,7 @@ static void set_scientific_object_data ()
 		{NULL}
 	};
 	
-	s_gfunc_map gfunc_map[] = {
+	static s_gfunc_map gfunc_map[] = {
 		{"button_sign", "-", display_result_toggle_sign},
 		{"button_ee", "e", display_append_e},
 		{"button_f1", "(", gfunc_f1},	/* paropen or swapxy */
@@ -201,7 +205,11 @@ static void set_scientific_object_data ()
 
 static void set_basic_object_data ()
 {
-	s_operation_map	operation_map[] = {
+	/* 20140316, simon: all these structs shall be static to have global scope.
+	 * fixes sf.net #104.
+	 */
+	
+	static s_operation_map operation_map[] = {
 		{"button_enter", "=", '='},
 		{"button_plus", "+", '+'},
 		{"button_minus", "-", '-'},
@@ -213,15 +221,15 @@ static void set_basic_object_data ()
 		{NULL}
 	};
 	
-	s_gfunc_map gfunc_map[] = {
+	static s_gfunc_map gfunc_map[] = {
 		{"button_sign", "-", display_result_toggle_sign},
 		{"button_f1", "(", gfunc_f1},	/* paropen or swapxy */
 		{"button_f2", ")", gfunc_f2},	/* parclose or rolldn */
 		{NULL}
 	};
 	
-	s_function_map function_map[] = {
-		{"button_sqrt", {"sqrt", "^2", "sqrt", "sqrt"}, {G_SQRT, powx2, G_SQRT, G_SQRT}},
+	static s_function_map function_map[] = {
+		{"button_sqrt", {"sqrt(", "^2", "sqrt(", "sqrt("}, {G_SQRT, powx2, G_SQRT, G_SQRT}},
 		{NULL}
 	};
 	
@@ -591,6 +599,9 @@ static void set_all_dispctrl_buttons_property (GtkCallback func, gpointer data)
 	if (!table) return;
     
     table_children = gtk_container_get_children(GTK_CONTAINER(table));
+    /* this fixes sf.net #107 */
+	if (!table_children) return;
+
 	/* dispctrl_right has an extra table for cosmetic reasons. */
 	if (GTK_IS_TABLE_OR_GRID (table_children->data))
 		table = (GTK_TABLE_OR_GRID *) GTK_WIDGET(table_children->data);
